### Encoding: UTF-8

### Name: SimulationStudy
### Title: Simulation study of family relationships
### Aliases: SimulationStudy
### Keywords: iteration htest

### ** Examples

  set.seed(17)
  models <- SetModels(trueModels=paste("HS-", 1:6, sep=""),
                      altModels=c("true", "unrelated"))
  nsim <- rep(10, 2)
  nmarker <- 22*c(1, 10)
  chr <- c(1:22)
  simObj1 <- SimulationStudy(models, chr=chr, nmarker=nmarker, nsim=nsim, maf=0.5)
  stat1 <- ComputeSummaryStatistics(simObj1)
  ## Average posterior results for no of markers=22:
  print(round(stat1$posterior[1,,],4)) # rows: true models, columns: alternative models
###        HS-1   HS-2   HS-3   HS-4   HS-5 HS-6 unrelated
### HS-1 0.5284     NA     NA     NA     NA   NA    0.4716
### HS-2     NA 0.4821     NA     NA     NA   NA    0.5179
### HS-3     NA     NA 0.4945     NA     NA   NA    0.5055
### HS-4     NA     NA     NA 0.5004     NA   NA    0.4996
### HS-5     NA     NA     NA     NA 0.5001   NA    0.4999
### HS-6     NA     NA     NA     NA     NA  0.5    0.5000
  ## No of markers=220:
  print(round(stat1$posterior[2,,],4))

  ## Simulation study using Affymetrix frequency data
  ## The complete 500K data file may be downloaded from
  ## 'http://folk.uio.no/thoree/FEST/affy.RData'
  ## load("affy.RData")

  ## A small subset of the Affymetrix frequency data. 100 markers on
  ## each chromsome
  data(affy.subset)
  simObj2 <- SimulationStudy(models, chr=chr, nmarker=nmarker, nsim=nsim,
                             frequencyData=affy.subset, freqThreshold=c(0.1,0.1))
  stat2 <- ComputeSummaryStatistics(simObj2)
  ## Average posterior results (Affymetrix):
  ## No of markers=22:
  print(round(stat1$posterior[1,,],4)) # rows: true models, columns: alternative models
  ## No of markers=220:
  print(round(stat1$posterior[2,,],4))



